# == Class: unbound
#
# Puppet module to install, deploy and configure unbound.
#
class unbound (
  $ensure_package      = $unbound::params::ensure_package,
  $ensure_service      = $unbound::params::ensure_service,
  $enable              = $unbound::params::enable,
  $package_name        = $unbound::params::package_name,
  $service_name        = $unbound::params::service_name,
  $user_name           = $unbound::params::user_name,
  $group_name          = $unbound::params::group_name,
  $config_file         = $unbound::params::config_file,
  $verbosity           = $unbound::params::verbosity,
  $interfaces          = $unbound::params::interfaces,
  $access_control      = $unbound::params::access_control,
  $doipv4              = $unbound::params::doipv4,
  $doipv6              = $unbound::params::doipv6,
  $dotcp               = $unbound::params::dotcp,
  $doudp               = $unbound::params::doudp,
  $hideidentity        = $unbound::params::hideidentity,
  $hideversion         = $unbound::params::hideversion,
  $hardenglue          = $unbound::params::hardenglue,
  $usecapsforid        = $unbound::params::usecapsforid,
  $donotquerylocalhost = $unbound::params::donotquerylocalhost,
  $forwardzonename     = $unbound::params::forwardzonename,
  $forwardaddrs        = $unbound::params::forwardaddrs,
  $privatedomains      = $unbound::params::privatedomains,
  $domaininsecures     = $unbound::params::domaininsecures,
  $include             = $unbound::params::include,
  $moduleconfig        = $unbound::params::moduleconfig
) inherits unbound::params {

  # Package management.
  package { $package_name:
      ensure => $ensure_package
  }

  # Service management.
  service { $service_name:
    ensure     => $ensure_service,
    enable     => $enable,
    hasrestart => true,
    hasstatus  => true,
    require    => Package[$package_name]
  }

  # Files management.
  file { $config_file:
    ensure  => $ensure_package,
    backup  => true,
    path    => $config_file,
    owner   => $user_name,
    group   => $group_name,
    mode    => '0644',
    content => template('unbound/unbound.conf.erb'),
    require => Package[$package_name],
    notify  => Service[$service_name],
  }
}
