# == Class: unbound::params
#
# This is a container class holding default parameters for unbound module.
#
class unbound::params {
  # Defaults values.
  $ensure_package      = 'present'
  $ensure_service      = 'running'
  $enable              = true

  $verbosity           = '1'
  $interfaces          = [
    '127.0.0.1'
  ]
  $access_control      = [
    '0.0.0.0/0 refuse',
    '127.0.0.0/8 allow'
  ]
  $doipv4              = 'yes'
  $doipv6              = 'no'
  $dotcp               = 'yes'
  $doudp               = 'yes'
  $hideidentity        = yes
  $hideversion         = yes
  $hardenglue          = yes
  $usecapsforid        = yes
  $donotquerylocalhost = yes

  $privatedomains      = []
  $domaininsecures     = []
  $moduleconfig        = undef

  $forwardzonename     = '.'
  $forwardaddrs        = [
    '8.8.8.8',
    '8.8.4.4'
  ]

  # Create variables depending on OS.
  case $::operatingsystem {
    /(Debian|Ubuntu)/          : {
      $package_name = 'unbound'
      $service_name = 'unbound'
      $user_name    = 'root'
      $group_name   = 'root'
      $config_file  = '/etc/unbound/unbound.conf'
      $include      = '/etc/unbound/unbound.conf.d/*.conf'
    }
    /(CentOS|Fedora|RedHat)/   : {
      $package_name = 'unbound'
      $service_name = 'unbound'
      $user_name    = 'root'
      $group_name   = 'root'
      $config_file  = '/etc/unbound/unbound.conf'
      $include      = undef
    }
    /(FreeBSD|NetBSD|OpenBSD)/ : {
      $package_name = 'unbound'
      $service_name = 'unbound'
      $user_name    = 'root'
      $group_name   = 'wheel'
      $config_file  = '/etc/unbound/unbound.conf'
      $include      = undef
    }
    default                    : {
      fail("Module template is not supported on ${::operatingsystem}")
    }
  }
}
# EOF
